@@ -17,22 +17,26 @@
 // Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 // Boston, MA  02111-1307, USA.
 //
-// $Id: screen-dump.cxx,v 1.2 2002/12/10 19:12:35 curt Exp $
+// $Id: screen-dump.cxx,v 1.4 2004/03/17 10:31:35 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
 #  include <simgear_config.h>
 #endif
 
-#ifdef HAVE_WINDOWS_H
-#  include <windows.h>                     
+#if defined(__CYGWIN__)  /* && !defined(USING_X) */
+#define WIN32
+#endif
+
+#if defined(WIN32)  /* MINGW and MSC predefine WIN32 */
+# include <windows.h>
 #endif
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <limits.h>
 
-#include GLUT_H
+#include <GL/gl.h>
 
 #include "screen-dump.hxx"
 
